<?php
namespace FM\Controller;

use FM\Controller\FMCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use FM\Service\VistoriasService;

class VistoriasController extends FMCrud{
    protected $dataSourceName = 'fcm_checklistagend';
    protected $VistoriasService;

    public function __construct($crudService, $environment, VistoriasService $VistoriasService) {
        parent::__construct($crudService, $environment);
        $this->VistoriasService = $VistoriasService;
    }

    // Busca nome e local da vistoria
    public function getInspectionNameAndLocal(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();
        
        $var = $this->VistoriasService->getInspectionNameAndLocal($params['id']);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }

    // Busca as vistorias e algumas informações entras
    public function getInspectionsInfo(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();

        $var = $this->VistoriasService->getInspectionsInfo($params['params']);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }

    // Busca critérios
    public function getCriteria(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();

        $var = $this->VistoriasService->getCriteria($params['id']);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }

    // Busca Vistorias para edição
    public function getInspectionToUpdate(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();

        $nrgerenciamentochk = $params['params']['NRGERENCIAMENTOCHK'];
        $nratividadechk = $params['params']['NRATIVIDADECHK'];

        $var = $this->VistoriasService->getInspectionToUpdate($nrgerenciamentochk, $nratividadechk);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }

    // Busca as atividades da Vistoria
     public function getActivities(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();

        $id = $params['id'];

        $var = $this->VistoriasService->getActivities($id);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }

    // Salva as informações de Vistoria
    public function updateInspection(DTO\Request $request, DTO\Response $response) {
        $params = $request->getParameters();

        $idSituacaoAgend      = $params['idSituation'];
        $nrgerenciamentochk   = $params['params']['NRGERENCIAMENTOCHK'];
        $nrcriteriotargerchk  = $params['params']['NRCRITERIOTARGERCHK'];
        $nrcriteriotargerchks = $params['params']['NRCRITERIOTARGERCHKS'];
        $nrtarefagerchk       = $params['params']['NRTAREFAGERCHK'];
        $dsobstarefagerchk    = $params['params']['DSOBSTAREFAGERCHK'];
        $nratividadechk       = $params['params']['NRATIVIDADECHK'];
        // $nrfototarefagerchk = $params['params']['NRFOTOTAREFAGERCHK'];

        $var = $this->VistoriasService->updateInspection($idSituacaoAgend, $nrgerenciamentochk, $nrcriteriotargerchk, $nrcriteriotargerchks, $nrtarefagerchk, $dsobstarefagerchk, $nratividadechk);
        $dtsVal = new DataSet('info', [$var]);
        $response->addDataSet($dtsVal);

    }

    // Responsável por baixar o aquivo do fileserver
    public function downloadDocFileServer(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();

            $nrseqmoddocfct = $row["NRSEQMODDOCFCT"];
            $nrorg = $this->environment->getNrOrg();

            $result = $this->VistoriasService->downloadDocFileServer($nrseqmoddocfct, $nrorg);
            $response->addDataSet(new DataSet("URLDOCUMENTO", array($result)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function uploadPictures(DTO\Request $request, DTO\Response $response) {
        $params = $request->getDataSet();
        $var = $this->VistoriasService->getInspectionNameAndLocal($params);
        $dtsVal = new DataSet('info', $var);
        $response->addDataSet($dtsVal);
    }
}
?>