/* eslint-disable no-console */
import {
  Metadata, Http,
  IDictionary, Router,
  IEventParam,
} from '@zeedhi/core';
import {
  Select, Switch, DialogService,
  Container, Form, TextInput,
  Button, Text, Col,
} from '@zeedhi/common';
import ColorPicker from '@/components/colorPicker/ZdColorPicker';
import { getRouteParams } from '../router';

export class LocalAtendimentoController {
  public dataValue: string = '';

  public editable = false;

  // Lista para cada campo da tela
  public localDataList: IDictionary = {
    SelectCliente: [],
    localTypeLocalAt: [],
    localParentLocalAt: [],
    sectorLocalAt: [],
    group: [],
    employee: [],
    checkListLocalAt: [],
  };

  // Inicializar os meus dados
  public inicializarDados() {
    Promise.all([this.setLocal(), this.setLocalParent(), this.setSector(), this.setCheckList(), this.setCliente()]).then(() => {
      this.getToUpdate();
    });
    // this.setGroup();
    // this.setEmployee();
  }

  // Setar dados dentro da minha lista
  public setDados(nome: string, code:number) {
    return {
      name: nome,
      value: code,
    };
  }

  // Seta dados especificamente para o campo "Tipo de Local"
  public setDadosLocal(nome: string, code:number, dif:string) {
    return {
      name: nome,
      value: code,
      addInfo: dif,
    };
  }

  // Habilita o campo checklist
  public validaCheckListPadrao({ component }: IEventParam<Select>) {
    const checkListObject = Metadata.getInstance<Select>('checkListLocalAt');
    const valid = component.datasource.data.filter((infos) => (component.value === infos.value));
    const localParentAtObject = Metadata.getInstance<Select>('localParentLocalAt');

    if (valid[0].addInfo === '3') {
      checkListObject.disabled = false;
    } else {
      checkListObject.disabled = true;
      checkListObject.setValue('');
    }
    if (valid[0].addInfo === '1') {
      localParentAtObject.disabled = true;
      localParentAtObject.setValue('');
      localParentAtObject.removeValidation('required');
      this.organizeCampos(true);
    } else {
      localParentAtObject.disabled = false;
      localParentAtObject.addValidation('required');
      this.organizeCampos(false);
      // colorPickerObject.value.hexa = '';
    }
  }

  // Organiza os campos para exibir ou esconder o ZdColorPicker
  public organizeCampos(condicao: boolean) {
    const ColComSelects = Metadata.getInstance<Col>('ColComSelects');
    const ColComColorPicker = Metadata.getInstance<Col>('ColComColorPicker');
    const formPai = Metadata.getInstance<Form>('inputFormLocalAt');
    if (condicao) {
      ColComSelects.cols = '8';
      ColComColorPicker.isVisible = true;
      formPai.children[1].grid!.cols = '4';
      formPai.children[0].grid!.cols = '4';
      formPai.children[2].grid!.cols = '4';
      formPai.children[5].grid!.cols = '4';
      formPai.children[6].grid!.cols = '4';
      formPai.children[7].grid!.cols = '4';
      formPai.children[8].grid!.cols = '4';
      formPai.cssStyle = {
        'border-right': '1px solid #d8d7d3',
        'padding-right': '2em',
      };
    } else {
      ColComSelects.cols = '12';
      ColComColorPicker.isVisible = false;
      formPai.children[0].grid!.cols = '3';
      formPai.children[1].grid!.cols = '3';
      formPai.children[2].grid!.cols = '3';
      formPai.children[5].grid!.cols = '3';
      formPai.children[6].grid!.cols = '3';
      formPai.children[7].grid!.cols = '3';
      formPai.children[8].grid!.cols = '3';
      formPai.cssStyle = {};
    }
  }

  // Torna visível o field group Tarefa Programada (Não está sendo usado)
  public isVisibleContainer() {
    const containerObject = Metadata.getInstance<Container>('task_container');
    const checkListObject = Metadata.getInstance<Select>('checkListLocalAt');
    const switchObject = Metadata.getInstance<Switch>('switch');

    if (checkListObject.value && switchObject.value) {
      containerObject.isVisible = true;
    } else {
      containerObject.isVisible = false;
    }
  }

  public consoleLog({ component }: {component: ColorPicker}) {
    console.log(component);
    const titulo = Metadata.getInstance<Text>('titulo');
    titulo.text = 'text';
  }

  // Form validation
  public createClick() {
    const formObject = Metadata.getInstance<Form>('inputFormLocalAt');
    const formValidate1 = formObject.validate();

    if (formValidate1) {
      this.insertLocalInfos();
      Router.replace('/gerenciarLocais');
    }
  }

  // Setando valores do campo "Cliente"
  public setCliente() {
    return new Promise((resolve, reject) => {
      try {
        Http.get('/getClient').then((response: IDictionary) => {
          response.data.dataset.clientes.forEach((dados: IDictionary) => {
            this.localDataList.SelectCliente.push({ name: dados.NMFANTCLIE, value: dados.CDCLIENTE });
          });
          resolve();
        });
      } catch (error) {
        reject(error);
      }
    });
  }

  // Setando valores do campo "Tipo de Local"
  public setLocal() {
    return new Promise((resolve, reject) => {
      try {
        Http.get('/getLocalType').then((response: IDictionary) => {
          response.data.dataset.options.forEach((dados: IDictionary) => {
            this.localDataList.localTypeLocalAt.push(this.setDadosLocal(dados.NMTIPOLOCALCLI, dados.NRTIPOLOCALCLI, dados.IDTIPOLOCALCLI));
          });
          resolve();
        });
      } catch (error) {
        reject(error);
      }
    });
  }

  // Setando valores do campo [LocalParent]
  public setLocalParent() {
    return new Promise((resolve, reject) => {
      try {
        Http.get('/getLocalParent').then((response: IDictionary) => {
          response.data.dataset.options.forEach((dados: IDictionary) => {
            this.localDataList.localParentLocalAt.push(this.setDados(dados.NMLOCALCLIENTE, dados.NRLOCALCLIENTE));
          });
          resolve();
        });
      } catch (error) {
        reject(error);
      }
    });
  }

  // Setando valores do campo "Setor"
  public setSector() {
    return new Promise((resolve, reject) => {
      try {
        Http.get('/getSector').then((response: IDictionary) => {
          response.data.dataset.options.forEach((dados: IDictionary) => {
            this.localDataList.sectorLocalAt.push(this.setDados(dados.NMSETOR, dados.NRSETOR));
          });
          resolve();
        });
      } catch (error) {
        reject(error);
      }
    });
  }

  // Setando valores do campo "Grupo"
  // public setGroup() {
  //   Http.get('/getGroup').then((response: IDictionary) => {
  //     response.data.dataset.options.forEach((dados: IDictionary) => {
  //       this.localDataList.group.push(this.setDados(dados.NMGRUPOLOCAL, dados.NRGRUPOLOCAL));
  //     });
  //   });
  // }

  // Setando valores do campo "Funcionário"
  // public setEmployee() {
  //   Http.get('/getEmployee').then((response: IDictionary) => {
  //     response.data.dataset.options.forEach((dados: IDictionary) => {
  //       this.localDataList.employee.push(this.setDados(dados.NMFUNCIONARIO, dados.NRFUNCIONARIO));
  //     });
  //   });
  // }

  // Setando valores do campo "Check List Padrão
  public setCheckList() {
    return new Promise((resolve, reject) => {
      try {
        Http.get('/getCheckListLocalAtend').then((response: IDictionary) => {
          response.data.dataset.options.forEach((dados: IDictionary) => {
            this.localDataList.checkListLocalAt.push(this.setDados(dados.NMCHECKLIST, dados.NRCHECKLIST));
          });
          resolve();
        });
      } catch (error) {
        reject(error);
      }
    });
  }

  // Salvando no data do component para exibir na tela
  public findDados({ component }:any) {
    component.datasource.data = this.localDataList[component.name];
  }

  /*  --------- Inserts ----------  */

  public insertLocalInfos() {
    const params = {
      NMLOCALCLIENTE: Metadata.getInstance<TextInput>('nameLocalAt').value,
      CDCLIENTE: Metadata.getInstance<Select>('sectorLocalAt').value,
      NRTIPOLOCALCLI: Metadata.getInstance<Select>('localTypeLocalAt').value,
      NRLOCALCLIENTEPAI: Metadata.getInstance<Select>('localParentLocalAt').value,
      NRCHECKLISTPADR: Metadata.getInstance<Select>('checkListLocalAt').value,
      NRSETOR: Metadata.getInstance<Select>('sectorLocalAt').value,
      DSICONELOCAL: null,
      DSQRCODE: null,
      NRORG: 20,
      CDOPERINCLUSAO: '000000004280',
      NRORGINCLUSAO: 20,
      DTULTATU: null,
      CDOPERULTATU: null,
      NRORGULTATU: null,
      NRGRUPOLOCAL: null,
      DSCODIGOLOCALCLI: Metadata.getInstance<TextInput>('codeLocalAt').value,
      DSCORIDLOCAL: Metadata.getInstance<ColorPicker>('colorPicker').value || null,
    };
    Http.post('/insertLocalAt', { params }).then((response: IDictionary) => {
      if (response.data.dataset.options.error) {
        DialogService.show({
          name: 'errorDialogLocal',
          type: 'error',
          title: 'Não foi possível completar a ação',
          text: 'Tente novamente. Se o problema persistir contate a manutenção.',
        });
      }
    });
  }

  // Inserir tarefa programada (Não está sendo usado)
  // public insertTaskInfos() {
  //   const params = {
  //     NRCHECKLISTAGEND: Metadata.getInstance<Select>('checkListLocalAt').value,
  //     NRFUNCIONARIO: Metadata.getInstance<Select>('employee').value,
  //     DSOBSTAREFAAGEND: null,
  //     NRORG: 20,
  //     CDOPERINCLUSAO: '000000004280',
  //     NRORGINCLUSAO: 20,
  //     DTULTATU: null,
  //     CDOPERULTATU: null,
  //     NRORGULTATU: null,
  //   };

  //   const test = {
  //     teste: [],
  //   };

  //   test.teste.push(params);
  //   // Http.post('/insertTask', { params })
  // }

  /*  --------- Updates ----------  */

  public getToUpdate() {
    const routeParams = getRouteParams();
    const { nr } = routeParams;

    const params = {
      NRLOCALCLIENTE: nr,
    };

    Http.post('/getLocalAtToUpdate', { params }).then((response) => {
      response.data.dataset.options.forEach((dados: IDictionary) => {
        Metadata.getInstance<Text>('nrLocalAt').text = dados.NRLOCALCLIENTE;
        Metadata.getInstance<TextInput>('nameLocalAt').value = dados.NMLOCALCLIENTE;
        Metadata.getInstance<Select>('localTypeLocalAt').setValue(Number(dados.NRTIPOLOCALCLI));
        Metadata.getInstance<Select>('localParentLocalAt').setValue(dados.NRLOCALCLIENTEPAI);
        Metadata.getInstance<Select>('sectorLocalAt').setValue(dados.NRSETOR);
        Metadata.getInstance<Select>('checkListLocalAt').setValue(dados.NRCHECKLISTPADR);
        Metadata.getInstance<TextInput>('codeLocalAt').value = dados.DSCODIGOLOCALCLI;
        Metadata.getInstance<ColorPicker>('colorPicker').value = dados.DSCORIDLOCAL;
        this.setUpdate();
      });
    });
  }

  // Muda o label do botao criar e chama atribui o evento de click update para ele
  public setUpdate() {
    const buttonObject = Metadata.getInstance<Button>('saveButtonLocalAt');
    buttonObject.label = 'Salvar';
    buttonObject.events = {
      click: () => this.finalUpdate(),
    };
  }

  // Atualiza os dados do Local de Atendimento
  public finalUpdate() {
    const params = {
      NRLOCALCLIENTE: Metadata.getInstance<Text>('nrLocalAt').text,
      NMLOCALCLIENTE: Metadata.getInstance<TextInput>('nameLocalAt').value,
      NRTIPOLOCALCLI: Metadata.getInstance<Select>('localTypeLocalAt').value,
      NRLOCALCLIENTEPAI: Metadata.getInstance<Select>('localParentLocalAt').value,
      NRCHECKLISTPADR: Metadata.getInstance<Select>('checkListLocalAt').value,
      NRSETOR: Metadata.getInstance<Select>('sectorLocalAt').value,
      DSCODIGOLOCALCLI: Metadata.getInstance<TextInput>('codeLocalAt').value,
      DSCORIDLOCAL: Metadata.getInstance<ColorPicker>('colorPicker').value,
    };
    Router.replace('/gerenciarLocais');
    Http.post('/updateLocalAt', { params }).then((response: IDictionary) => {
      if (response.data.dataset.options.error) {
        DialogService.show({
          name: 'errorDialogLocal',
          type: 'error',
          title: 'Não foi possível completar a ação',
          text: 'Tente novamente. Se o problema persistir contate a manutenção.',
        });
      }
    });
  }

  // Abre a tela com o local superior já preenchido
  public setParentLocal({ component }: IEventParam<Button>) {
    Router.replace('/localAtendimento/null');
    setTimeout(() => {
      Metadata.getInstance<Select>('localParentLocalAt').setValue(Number(component.name.substr(3)));
    }, 750);
  }
}
