import {
  Http, IDictionary,
} from '@zeedhi/core';
import { Modal, ModalService } from '@zeedhi/common';

export class ModalPAcessoController {
  private modalSetor!: Modal;

  private modalFuncao!: Modal;

  private modalUsuario!: Modal;

  /* -------- Criar Modais -------- */

  public async createModalSetor() {
    this.modalSetor = await ModalService.createFromJson('/modal/modalNovoSetor', true);
  }

  public async createModalFuncao() {
    this.modalFuncao = await ModalService.createFromJson('/modal/modalNovaFuncao', true);
  }

  public async createModalUsuario() {
    this.modalUsuario = await ModalService.createFromJson('/modal/modalNovoUsuario', true);
  }

  /* -------- Destruir Modais -------- */

  public destroyModalSetor() {
    this.modalSetor.destroy();
  }

  public destroymodalFuncao() {
    this.modalFuncao.destroy();
  }

  public destroyModalUsuario() {
    this.modalUsuario.destroy();
  }

  /* -------- Abrir Modais -------- */

  public openModalSetor() {
    this.modalSetor.show();
  }

  public openModalFuncao() {
    this.modalFuncao.show();
  }

  public openModalUsuario() {
    this.modalUsuario.show();
  }

  /* -------- Fechar Modais -------- */

  public closeModalSetor() {
    this.modalSetor.hide();
  }

  public closeModalFuncao() {
    this.modalFuncao.hide();
  }

  public closeModalUsuario() {
    this.modalUsuario.hide();
  }

  /* ---------- Inicializações ---------- */

  public selectsData: IDictionary = {
    positionSelect: [],
    sectorSelect: [],
    userSelect: [],
  };

  // Função e Setor
  public initializeData() {
    this.setPositionSelect();
    this.setSectorSelect();
  }

  // Usuário
  public initializeUserData() {
    this.setUserSelect();
  }

  public setData(infoName: string, infoValue: number) {
    return {
      name: infoName,
      value: infoValue,
    };
  }

  public setSelectsData({ component }: any) {
    component.datasource.data = this.selectsData[component.name];
  }

  /* ---------- Selects ---------- */

  // Seta "Funções" no Select "Função"
  public setPositionSelect() {
    Http.get('/positionsList').then((response: IDictionary) => {
      response.data.dataset.info.forEach((database: IDictionary) => {
        this.selectsData.positionSelect.push(this.setData(database.NMPERFILACESSO, database.NRPERFILACESSO));
      });
    });
  }

  // Seta "Setores" no Select "Setor"
  public setSectorSelect() {
    Http.get('/sectorsList').then((response: IDictionary) => {
      response.data.dataset.info.forEach((database: IDictionary) => {
        this.selectsData.sectorSelect.push(this.setData(database.NMSETOR, database.NRSETOR));
      });
    });
  }

  // Seta "Usuários" no select "Responsável"
  public setUserSelect() {
    Http.get('/usersList').then((response: IDictionary) => {
      response.data.dataset.info.forEach((database: IDictionary) => {
        this.selectsData.userSelect.push(this.setData(database.NMFUNCIONARIO, database.NRFUNCIONARIO));
      });
    });
  }
}
